# HeavyBall

A simple package of many optimizers

The goal is not to thrive for completeness, full maintenance or abstraction, but instead to provide a simple
largely static alternative to `torch.optim` with more and better optimizers.

The code is permissively licensed under the BSD-2-Clause license, so you may copy the individual files into your
repository instead of depending on this package.